From 097910af8bf8194c792972af96f03c8bc277e47f Mon Sep 17 00:00:00 2001
From: DCoded <dcoded@live.com>
Date: Mon, 15 Apr 2019 22:02:44 -0400
Subject: [PATCH] Replaced colour with color

---
 devNotes/legacy files/artWidgets-legacy |  4 +-
 src/art/vector/VectorArtJS.js           | 89 +++++++++++++------------
 src/js/slaveSummaryWidgets.js           |  3 +-
 src/uncategorized/wardrobeUse.tw        | 18 ++---
 4 files changed, 58 insertions(+), 56 deletions(-)

diff --git a/devNotes/legacy files/artWidgets-legacy b/devNotes/legacy files/artWidgets-legacy
index 2ab0c78478d..a07b0a3534b 100644
--- a/devNotes/legacy files/artWidgets-legacy	
+++ b/devNotes/legacy files/artWidgets-legacy	
@@ -82,9 +82,9 @@ $args[2]: icon UI Display for vector art, 1 for on.
 	<<print "<img class='paperdoll' src=" + _folderLoc + "/test ui.svg'" + "/>">>
 <</if>>
 
-/% Set skin colour %/
+/% Set skin color %/
 <<set _skinFilter = "filter: url(#skin-" + _.kebabCase($args[0].skin) + ");">>
-/% Set hair colour %/
+/% Set hair color %/
 <<set _hairFilter = "filter: url(#hair-" + _.kebabCase($args[0].hColor) + ");">>
 <<set _pubesFilter = "filter: url(#hair-" + _.kebabCase($args[0].pubicHColor) + ");">>
 <<set _axillaryFilter = "filter: url(#hair-" + _.kebabCase($args[0].underArmHColor) + ");">>
diff --git a/src/js/slaveSummaryWidgets.js b/src/js/slaveSummaryWidgets.js
index 3f532330122..d65865f6718 100644
--- a/src/js/slaveSummaryWidgets.js
+++ b/src/js/slaveSummaryWidgets.js
@@ -5098,7 +5098,8 @@ App.UI.slaveSummaryList = function (passageName) {
 
 	const _indexed = 0;
 	/**
-	 * @type {App.Entity.SlaveState[]} */
+	 * @type {App.Entity.SlaveState[]}
+	 */
 	const slaves = V.slaves;
 
 	V.assignTo = passageName; // would be passed to the "Assign" passage
diff --git a/src/uncategorized/wardrobeUse.tw b/src/uncategorized/wardrobeUse.tw
index 5ef36b31c63..55f6fde4b6d 100644
--- a/src/uncategorized/wardrobeUse.tw
+++ b/src/uncategorized/wardrobeUse.tw
@@ -251,12 +251,12 @@
 	<<if ($seeImages == 1) && ($imageChoice == 1)>>
 		/* prepare display of currently selected color. */
 		/* TODO: update currently selected color upon outfit select */
-		/* _clothingBaseColor is set by display (Art_Vector_Set_Colour_Shoe_), but not all outfits define a color. */
-		/* _skinColour is used as fallback default (set by Art_Vector_Set_Colour_Skin_). */
-		<<set _clothingBaseColor = _skinColour >>
-		<<if def _outfitBaseColour>>
+		/* _clothingBaseColor is set by display (Art_Vector_Set_Color_Shoe_), but not all outfits define a color. */
+		/* _skinColor is used as fallback default (set by Art_Vector_Set_Color_Skin_). */
+		<<set _clothingBaseColor = _skinColor >>
+		<<if def _outfitBaseColor>>
 			/* set default color predefined by choice of outfit */
-			<<set _clothingBaseColor = _outfitBaseColour>>
+			<<set _clothingBaseColor = _outfitBaseColor>>
 		<</if>>
 		<<if def $activeSlave.clothingBaseColor>>
 			/* regard current user selection */
@@ -327,7 +327,7 @@ Collar: ''$activeSlave.collar.''
 
 	<<if ($seeImages == 1) && ($imageChoice == 1)>>
 		/* prepare display of currently selected color. */
-		/* _glassesColor is always set by display (Art_Vector_Set_Colour_Outfit_) */
+		/* _glassesColor is always set by display (Art_Vector_Set_Color_Outfit_) */
 		<<if def $activeSlave.glassesColor>>
 			/* regard current user selection */
 			<<set _glassesColor = $activeSlave.glassesColor>>
@@ -369,14 +369,14 @@ Collar: ''$activeSlave.collar.''
 	<<if ($seeImages == 1) && ($imageChoice == 1) && $activeSlave.shoes != "none">>
 		&nbsp;&nbsp;&nbsp;&nbsp;//Color://&nbsp;&nbsp;
 		/* prepare display of currently selected color. */
-		/* _shoeColour is always set by display (Art_Vector_Set_Colour_Shoe_) */
+		/* _shoeColor is always set by display (Art_Vector_Set_Color_Shoe_) */
 		/* TODO: update currently selected color upon shoe select */
 		<<if def $activeSlave.shoeColor>>
 			/* regard current user selection */
-			<<set _shoeColour = $activeSlave.shoeColor>>
+			<<set _shoeColor = $activeSlave.shoeColor>>
 		<</if>>
 		/* Display an HTML5 color picker */
-		<<colorinput "$activeSlave.shoeColor" _shoeColour>>
+		<<colorinput "$activeSlave.shoeColor" _shoeColor>>
 		<<if def $activeSlave.shoeColor>>
 			&nbsp;&nbsp;[[Reset default color|Wardrobe Use][delete $activeSlave.shoeColor]]
 		<</if>>
diff --git a/src/art/vector/VectorArtJS.js b/src/art/vector/VectorArtJS.js
index 50288a37e6e..c729ca2efce 100644
--- a/src/art/vector/VectorArtJS.js
+++ b/src/art/vector/VectorArtJS.js
@@ -70,15 +70,16 @@ window.VectorArt = (function () {
 
 		/* prepare HTML color codes for slave display */
 		/* note: latex clothing is mostly emulated by rubber color for skin (and shoes) */
-		/* TODO: consistently use American "color" instead of "colour" for all identifiers */
 		ArtVectorColor(slave);
 
 		/* displayClass is the style class for this display */
 		if (T.art_display_id > 0)
 			T.art_display_id++;
 		else
+			// eslint-disable-next-line camelcase
 			T.art_display_id = 1;
 		displayClass = `ad${T.art_display_id}`;
+		// eslint-disable-next-line camelcase
 		T.art_display_class = displayClass;
 
 		/* setup height scaling and style */
@@ -106,7 +107,7 @@ window.VectorArt = (function () {
 				right: 0;\
 			}\
 			.${displayClass} .white{ fill:#FFFFFF; }\
-			.${displayClass} .skin{ fill:${T.skinColour}; }\
+			.${displayClass} .skin{ fill:${T.skinColor}; }\
 			.${displayClass} .head{ ${T.headSkinStyle}; }\
 			.${displayClass} .torso{ ${T.torsoSkinStyle}; }\
 			.${displayClass} .boob{ ${T.boobSkinStyle}; }\
@@ -116,16 +117,16 @@ window.VectorArt = (function () {
 			.${displayClass} .areola{ fill:${T.areolaStyle}; }\
 			.${displayClass} .bellybutton{ fill:${T.bellybuttonStyle}; }\
 			.${displayClass} .labia{ fill:${T.labiaStyle}; }\
-			.${displayClass} .hair{ fill:${T.hairColour}; }\
-			.${displayClass} .pubic_hair{ fill:${T.pubicHairColour}; }\
-			.${displayClass} .underarm_hair{ fill:${T.underarmHairColour}; }\
-			.${displayClass} .eyebrow_hair{ fill:${T.eyebrowHairColour}; }\
-			.${displayClass} .shoe{ fill:${T.shoeColour}; }\
-			.${displayClass} .shoe_shadow{ fill:${T.shoeShadowColour}; }\
+			.${displayClass} .hair{ fill:${T.hairColor}; }\
+			.${displayClass} .pubic_hair{ fill:${T.pubicHairColor}; }\
+			.${displayClass} .underarm_hair{ fill:${T.underarmHairColor}; }\
+			.${displayClass} .eyebrow_hair{ fill:${T.eyebrowHairColor}; }\
+			.${displayClass} .shoe{ fill:${T.shoeColor}; }\
+			.${displayClass} .shoe_shadow{ fill:${T.shoeShadowColor}; }\
 			.${displayClass} .smart_piercing{ fill:#4DB748; }\
 			.${displayClass} .steel_piercing{ fill:#787878; }\
 			.${displayClass} .steel_chastity{ fill:#BABABA; }\
-			.${displayClass} .outfit_base{ fill:${T.outfitBaseColour}; }\
+			.${displayClass} .outfit_base{ fill:${T.outfitBaseColor}; }\
 			.${displayClass} .gag{ fill:#BF2126; }\
 			.${displayClass} .shadow{ fill:#010101; }\
 			.${displayClass} .glasses{ fill:${T.glassesColor}; }\
@@ -1045,11 +1046,11 @@ window.VectorArt = (function () {
 	}
 
 	function ArtVectorColor() {
-		let outfitBaseColour;
+		let outfitBaseColor;
 
 		/*
 			WARNING: Some of these temporary variables are used in wardrobeUse.tw or salon.tw
-			Known examples are _outfitBaseColour, _glassesColor, and _shoeColour
+			Known examples are _outfitBaseColor, _glassesColor, and _shoeColor
 		*/
 		setOutfitColor();
 		setSkinColor();
@@ -1059,9 +1060,9 @@ window.VectorArt = (function () {
 		function setOutfitColor() {
 			/* TODO: rewrite all textual descriptions not to explicitly mention the latex being of black color. */
 			if (wearingLatex === true || slave.clothes === "a cybersuit")
-				outfitBaseColour = slave.clothingBaseColor || "#515351"; /* use custom color, or use default latex color */
+				outfitBaseColor = slave.clothingBaseColor || "#515351"; /* use custom color, or use default latex color */
 			else if (slave.clothes === "a comfortable bodysuit")
-				outfitBaseColour = slave.clothingBaseColor || "#464646"; /* use custom color, or use default bodysuit color */
+				outfitBaseColor = slave.clothingBaseColor || "#464646"; /* use custom color, or use default bodysuit color */
 
 			/* head addons */
 			if (slave.collar === "porcelain mask")
@@ -1070,7 +1071,7 @@ window.VectorArt = (function () {
 				T.glassesColor = slave.glassesColor || "#010101"; /* use custom color or default */
 
 			T.eyeColor = extractColor(slave.eyeColor, 1);
-			T.outfitBaseColour = outfitBaseColour;
+			T.outfitBaseColor = outfitBaseColor;
 		}
 
 		function setSkinColor() {
@@ -1080,7 +1081,7 @@ window.VectorArt = (function () {
 			T.areolaStyle = colorSlave.areolaColor;
 			T.bellybuttonStyle = colorSlave.areolaColor;
 			T.labiaStyle = colorSlave.labiaColor;
-			T.skinColour = colorSlave.skinColor;
+			T.skinColor = colorSlave.skinColor;
 			/* todo: introduce fleshStyle */
 			/* these need to be declared so they can be set conditionally */
 			T.headSkinStyle = undefined;
@@ -1093,37 +1094,37 @@ window.VectorArt = (function () {
 			/* BEGIN SKIN COLOR OVERRIDES FOR LATEX CLOTHING EMULATION */
 			if (slave.clothes === "a Fuckdoll suit") {
 				/* slave is a fuckdoll - display all skin as if it was black rubber */
-				T.skinColour = outfitBaseColour;
+				T.skinColor = outfitBaseColor;
 				T.areolaStyle = "fill:rgba(81,83,81,1);";
 				T.labiaStyle = T.areolaStyle;
 				T.bellybuttonStyle = T.areolaStyle;
 			} else if (slave.clothes === "restrictive latex") { /* slave wears restrictive latex - display most skin as if it was rubber */
 				/* nice latex does not cover any privates. */
-				T.boobSkinStyle = "fill:"+T.skinColour+";";
-				T.penisSkinStyle = "fill:"+T.skinColour+";";
-				T.scrotumSkinStyle = "fill:"+T.skinColour+";";
-				T.torsoSkinStyle = "fill:"+T.skinColour+";";
+				T.boobSkinStyle = "fill:"+T.skinColor+";";
+				T.penisSkinStyle = "fill:"+T.skinColor+";";
+				T.scrotumSkinStyle = "fill:"+T.skinColor+";";
+				T.torsoSkinStyle = "fill:"+T.skinColor+";";
 				/* rest of body is covered in latex */
-				T.skinColour = outfitBaseColour;
-				T.bellybuttonStyle = outfitBaseColour;
+				T.skinColor = outfitBaseColor;
+				T.bellybuttonStyle = outfitBaseColor;
 			} else if (slave.clothes === "a latex catsuit") {
 				/* nice latex does not cover head. */
-				T.headSkinStyle = "fill:"+T.skinColour+";";
+				T.headSkinStyle = "fill:"+T.skinColor+";";
 				/* rest of body is covered in latex */
-				T.skinColour = outfitBaseColour;
+				T.skinColor = outfitBaseColor;
 				/* catsuit covers areolae and crotch, too */
-				T.bellybuttonStyle = outfitBaseColour;
+				T.bellybuttonStyle = outfitBaseColor;
 			} else if (slave.clothes === "a cybersuit") {
 				/* rest of body is covered in latex */
-				T.skinColour = outfitBaseColour;
-				T.bellybuttonStyle = outfitBaseColour;
+				T.skinColor = outfitBaseColor;
+				T.bellybuttonStyle = outfitBaseColor;
 			} else if (slave.clothes === "a comfortable bodysuit") {
 				/* nice bodysuit does not cover head. */
-				T.headSkinStyle = "fill:"+T.skinColour+";";
+				T.headSkinStyle = "fill:"+T.skinColor+";";
 				/* rest of body is covered in bodysuit */
-				T.skinColour = outfitBaseColour;
-				T.bellySkinStyle = outfitBaseColour;
-				T.bellybuttonStyle = outfitBaseColour;
+				T.skinColor = outfitBaseColor;
+				T.bellySkinStyle = outfitBaseColor;
+				T.bellybuttonStyle = outfitBaseColor;
 			}
 			/* END SKIN COLOR OVERRIDES FOR LATEX CLOTHING EMULATION */
 
@@ -1402,30 +1403,30 @@ window.VectorArt = (function () {
 		}
 
 		function setHairColor() {
-			T.hairColour = extractColor(slave.hColor);
-			T.pubicHairColour = extractColor(slave.pubicHColor);
-			T.underarmHairColour = extractColor(slave.underArmHColor);
-			T.eyebrowHairColour = extractColor(slave.eyebrowHColor);
+			T.hairColor = extractColor(slave.hColor);
+			T.pubicHairColor = extractColor(slave.pubicHColor);
+			T.underarmHairColor = extractColor(slave.underArmHColor);
+			T.eyebrowHairColor = extractColor(slave.eyebrowHColor);
 			T.sclerae = extractColor(slave.sclerae);
 		}
 
 		function setShoeColor() {
 			/* BEWARE: _shoeColour is read by Wardrobe Use */
 			/* note: only heels use this _shoeShadowColour */
 
 			/* override color in case of full body latex outfit, or custom color*/
 			if (slave.clothes === "a Fuckdoll suit" || slave.clothes === "restrictive latex") {
-				T.shoeColour = T.skinColour;
-				T.shoeShadowColour = T.shoeColour+";opacity: 0.5"; /* TODO: do not abuse "color" variable for style definitions. do not rely on dark background for shadow effect either. */
+				T.shoeColor = T.skinColor;
+				T.shoeShadowColor = T.shoeColor+";opacity: 0.5"; /* TODO: do not abuse "color" variable for style definitions. do not rely on dark background for shadow effect either. */
 			} else if (slave.shoeColor !== undefined) {
-				T.shoeColour = slave.shoeColor+";opacity: 0.4"; /* shoe color selected by user */
-				T.shoeShadowColour = T.shoeColour+";opacity: 0.5"; /* TODO: do not abuse "color" variable for style definitions. do not rely on dark background for shadow effect either. */
+				T.shoeColor = slave.shoeColor+";opacity: 0.4"; /* shoe color selected by user */
+				T.shoeShadowColor = T.shoeColor+";opacity: 0.5"; /* TODO: do not abuse "color" variable for style definitions. do not rely on dark background for shadow effect either. */
 			} else {
-				T.shoeShadowColour = "#616a6b";
+				T.shoeShadowColor = "#616a6b";
 				if (slave.shoes === "none")
-					T.shoeColour = "#595959";
+					T.shoeColor = "#595959";
 				else
-					T.shoeColour = "#80808080";
+					T.shoeColor = "#80808080";
 			}
 		}
 	}
@@ -1402,30 +1403,30 @@ window.VectorArt = (function () {
 
 		function setShoeColor() {
-			/* BEWARE: _shoeColour is read by Wardrobe Use */
-			/* note: only heels use this _shoeShadowColour */
+			/* BEWARE: _shoeColor is read by Wardrobe Use */
+			/* note: only heels use this _shoeShadowColor */
 
 			/* override color in case of full body latex outfit, or custom color*/
-- 
GitLab